class Game {
  constructor() {
    this.canvas = document.getElementById('gameCanvas');
    this.gl = this.canvas.getContext('webgl');
    this.isPlaying = false;
    this.setupEventListeners();
    this.initWebGL();
  }

  setupEventListeners() {
    document.getElementById('playButton').addEventListener('click', () => {
      this.startGame();
    });

    document.getElementById('controls').addEventListener('click', () => {
      document.getElementById('instructions').classList.remove('hidden');
    });

    document.querySelector('.close').addEventListener('click', () => {
      document.getElementById('instructions').classList.add('hidden');
    });

    document.addEventListener('keydown', (e) => this.handleKeyPress(e));
    document.addEventListener('pointerlockchange', () => this.handlePointerLock());
  }

  initWebGL() {
    if (!this.gl) {
      alert('WebGL not supported');
      return;
    }

    // Basic WebGL setup
    this.gl.clearColor(0.529, 0.808, 0.922, 1.0); // Sky blue
    this.gl.clear(this.gl.COLOR_BUFFER_BIT | this.gl.DEPTH_BUFFER_BIT);
    this.gl.enable(this.gl.DEPTH_TEST);
    this.gl.viewport(0, 0, this.canvas.width, this.canvas.height);
  }

  startGame() {
    this.canvas.requestPointerLock();
    this.isPlaying = true;
    this.gameLoop();
  }

  handlePointerLock() {
    if (document.pointerLockElement === this.canvas) {
      this.isPlaying = true;
    } else {
      this.isPlaying = false;
    }
  }

  handleKeyPress(e) {
    if (!this.isPlaying) return;
    
    switch(e.code) {
      case 'KeyW':
        // Move forward
        break;
      case 'KeyS':
        // Move backward
        break;
      case 'KeyA':
        // Move left
        break;
      case 'KeyD':
        // Move right
        break;
      case 'Space':
        // Jump
        break;
      case 'Escape':
        document.exitPointerLock();
        break;
    }
  }

  gameLoop() {
    if (!this.isPlaying) return;

    // Clear the canvas
    this.gl.clear(this.gl.COLOR_BUFFER_BIT | this.gl.DEPTH_BUFFER_BIT);

    // Game update logic would go here

    requestAnimationFrame(() => this.gameLoop());
  }
}

// Initialize game when page loads
window.addEventListener('load', () => {
  const game = new Game();
});
